@@ -4,10 +4,6 @@
 
 . /opt/drbl/sbin/drbl-conf-functions
 
-# Settings
-# try IP from 192.168."100".254
-private_IP_alias_eth_def="100"
-
 # functions
 USAGE() {
     echo "To start, restart or stop DRBL service in DRBL Live environment."
@@ -50,85 +46,6 @@ set_locale_for_clients() {
   echo "Since some config files are modified in template client, recreating template tarball for DRBL SSI..."
   drbl-gen-ssi-files
 } # end of set_locale_for_clients
-#
-config_network(){
-  echo "Detecting the network status..."
-  eth_port_no="$(get-nic-devs | wc -l)"
-  configured_ip_no="$(get-all-nic-ip -i | wc -w)"
-  while [ "$configured_ip_no" -lt "$eth_port_no" ]; do
-    [ -n "$(route -n | grep -E "^0.0.0.0")" ] && config_gw_opt="--ignore-gw"
-    [ -n "$(grep -E "^[[:space:]]*nameserver[[:space:]]+\b(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\b" /etc/resolv.conf 2>/dev/null)" ] && config_dns_opt="--ignore-dns"
-    # find the configured ports, we will exclude them.
-    eth_ports="$(get-nic-devs)"
-    configured_port_list=""
-    for i in $eth_ports; do
-      if [ -n "$(drbl-get-ipadd $i)" ]; then
-       configured_port_list="$configured_port_list $i"
-      fi
-    done
-    if [ -n "$configured_port_list" ]; then
-      ocs-live-netcfg --ip-add " " $config_gw_opt $config_dns_opt --ignore-dv "$configured_port_list"
-    else
-      ocs-live-netcfg --ip-add " " $config_gw_opt $config_dns_opt
-    fi
-    configured_ip_no="$(get-all-nic-ip -i | wc -w)"
-    [ "$configured_ip_no" -eq "$eth_port_no" ] && break
-    [ "$BOOTUP" = "color" ] && $SETCOLOR_WARNING
-    echo $msg_do_not_assign_default_gw_for_DRBL_NIC
-    [ "$BOOTUP" = "color" ] && $SETCOLOR_NORMAL
-    echo "$msg_continue_to_conf_another_NIC"
-    echo -n "[Y/n] "
-    read continue_conf_eth
-    case "$continue_conf_eth" in
-       n|N|[nN][oO]) break ;;
-    esac
-  done
-
-  IP_no="$(get-all-nic-ip -i | wc -w)"
-  if [ "$IP_no" -eq 0 ]; then
-    [ "$BOOTUP" = "color" ] && $SETCOLOR_FAILURE
-    echo $msg_no_ip_address_is_configured
-    [ "$BOOTUP" = "color" ] && $SETCOLOR_NORMAL
-    echo "$msg_program_stop"
-    exit 1
-  elif [ "$IP_no" -eq 1 ]; then
-    [ "$BOOTUP" = "color" ] && $SETCOLOR_WARNING
-    echo "$msg_one_NIC_one_IP_limitation_prompt"
-    echo "$msg_if_lease_IP_add_to_pxe_etherboot_only"
-    [ "$BOOTUP" = "color" ] && $SETCOLOR_NORMAL
-    echo -n "[Y/n] "
-    read limit_pxeclient_ans
-    case "$limit_pxeclient_ans" in
-       n|N|[nN][oO]) limit_pxeclient="no" ;;
-       *) limit_pxeclient="yes" ;;
-    esac
-    echo -n "$msg_only_one_IP_so_create_alias_IP "
-    alias_done="no"
-    i="$private_IP_alias_eth_def"
-    while [ "$alias_done" = "no" ]; do
-      if ! ping -c 3 192.168.$i.254 &>/dev/null; then
-        ifconfig eth0:1 192.168.$i.254 netmask 255.255.255.0
-        alias_done="yes"
-      else
-        i=$((i+1))
-      fi
-    done
-    if ! egrep -e "^auto[[:space:]]+eth0:1" /etc/network/interfaces; then
-      cat <<-NET_END >> /etc/network/interfaces
-auto eth0:1
-iface eth0:1 inet static
-	address 192.168.$i.254
-	netmask 255.255.255.0
-NET_END
-    fi
-    echo "$msg_done!"
-  else
-    # More than one IP address, so it's not necessary to use alias IP address.
-    [ "$BOOTUP" = "color" ] && $SETCOLOR_WARNING
-    echo $msg_more_than_1_IP_some_for_DRBL_clients
-    [ "$BOOTUP" = "color" ] && $SETCOLOR_NORMAL
-  fi
-} # end of config_network
 
 
 #################
@@ -195,7 +112,7 @@ case "$switch" in
      fi
 
      # config network first:
-     config_network
+     config_drbl_live_network
 
      #
      if  [ "$prepare_ocsroot" = "yes" ]; then
